#
# spec file for package clucene-core
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           clucene-core
Version:        2.3.3.4
Release:        15.4
Summary:        CLucene is a C++ port of Lucene
License:        LGPL-2.1 or Apache-2.0
Group:          Development/Libraries/C and C++
Url:            http://clucene.sourceforge.net/

#Git-Clone:	git://clucene.git.sourceforge.net/gitroot/clucene/clucene
Source:         %{name}-%{version}.tar.bz2
Source2:        baselibs.conf
# PATCH-FIX-UPSTREAM [rh#748196]
Patch0:         clucene-2.3.3.4-pkgconfig.patch
# PATCH-FIX-UPSTREAM [rh#794795]
Patch1:         clucene-2.3.3.4-contrib-libs.patch
Patch2:         clucene-kill-ext-includes.diff

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CLucene is a C++ port of Lucene. It is a high-performance, full-featured text
search engine written in C++. CLucene is faster than lucene as it is written
in C++.

%package -n libclucene-core1
Summary:        C++ implementation of the Lucene text search engine
Group:          System/Libraries
# Rip the wrong name.
Obsoletes:      libclucene2 < %version-%release
Provides:       libclucene2 = %version-%release

%description -n libclucene-core1
CLucene is a C++ port of Lucene. It is a high-performance, full-featured text
search engine written in C++. CLucene is faster than lucene as it is written
in C++.

%package -n libclucene-shared1
Summary:        CLucene cross-platform layer
Group:          System/Libraries

%description -n libclucene-shared1
This package creates a library that is used in all the CLucene
projects. It provides cross-platform macros and functions, as well as
things like cl_* string macros, file handling functions, replacement
functions, etc.

%package -n libclucene-contribs-lib1
Summary:        Language specific text analyzers for %{name}
Group:          Development/Libraries/C and C++

%description -n libclucene-contribs-lib1
CLucene is a C++ port of Lucene. It is a high-performance, full-featured text
search engine written in C++. CLucene is faster than lucene as it is written
in C++.

This package contains language specific text analyzers for clucene.


%package devel
Summary:        Development files for clucene library
Group:          Development/Libraries/C and C++
Requires:       libclucene-contribs-lib1 = %{version}
Requires:       libclucene-core1 = %version
Requires:       libclucene-shared1 = %version
Requires:       libstdc++-devel

%description devel
CLucene is a C++ port of Lucene. It is a high-performance, full-featured text
search engine written in C++. CLucene is faster than lucene as it is written
in C++.

This package holds the development files for clucene.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch -P 2 -p1

# the tar ball is stripped like this:
rm -rf test/data/reuters* tests/data/utf* # test/data is not allowed to be distributed bnc#253602

%build
cmake . \
    -DCMAKE_CXX_FLAGS="%{optflags}" \
    -DCMAKE_C_FLAGS="%{optflags}" \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}" \
    -DLUCENE_SYS_INCLUDES=%{_libdir} \
    -DBUILD_CONTRIBS_LIB=ON \
%if "%_lib" == "lib64"
    -DLIB_SUFFIX=64 \
%endif
    -DCMAKE_BUILD_TYPE=RelWithDebInfo
make %{?_smp_mflags} VERBOSE=1

%install
make install DESTDIR="%buildroot"

rm -f %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_libdir}/CLuceneConfig.cmake

%post   -n libclucene-core1 -p /sbin/ldconfig
%postun -n libclucene-core1 -p /sbin/ldconfig
%post   -n libclucene-shared1 -p /sbin/ldconfig
%postun -n libclucene-shared1 -p /sbin/ldconfig

%files -n libclucene-core1
%defattr(-,root,root,-)
%doc APACHE.license AUTHORS ChangeLog COPYING doc/ LGPL.license  NEWS  README README.PACKAGE REQUESTS
%{_libdir}/libclucene-core.so.1
%{_libdir}/libclucene-core.so.%version

%files -n libclucene-shared1
%defattr(-,root,root)
%doc APACHE.license COPYING LGPL.license
%{_libdir}/libclucene-shared.so.1
%{_libdir}/libclucene-shared.so.%version

%post -n libclucene-contribs-lib1 -p /sbin/ldconfig
%postun -n libclucene-contribs-lib1 -p /sbin/ldconfig

%files -n libclucene-contribs-lib1
%defattr(-, root, root, -)
%{_libdir}/libclucene-contribs-lib.so.1*
%{_libdir}/libclucene-contribs-lib.so.%{version}

%files devel
%defattr(-,root,root,-)
%{_libdir}/libclucene*.so

%{_includedir}/CLucene*
%dir %{_libdir}/CLucene/
%{_libdir}/CLucene/clucene-config.h

%{_libdir}/CLucene/CLuceneConfig.cmake
%{_libdir}/pkgconfig/libclucene-core.pc

%changelog
* Fri Jan 25 2013 jengelh@inai.de
- Replace wrong shlib package name "libclucene2" (the SONAME is
  libclucene*.so.1, not .2) by libclucene-{core,shared}1
- Use more robust make install command
- Add patch clucene-kill-ext-includes.diff
* Mon Dec 17 2012 ro@suse.de
- fix build on s390x which also uses lib64
* Wed Mar 21 2012 tchvatal@suse.cz
- build contrib libs too
* Thu Mar 15 2012 dvaleev@suse.com
- fix ppc64 build
* Fri Nov 25 2011 saschpe@suse.de
- Avoid line continuation in last cmake parameter
* Fri Nov 25 2011 dev@dominik-schmidt.de
- Fixed typo in cmake arguments
* Thu Nov 24 2011 saschpe@suse.de
- Darix doesn't want a renamed devel package, thus revert that part
* Wed Nov 23 2011 tittiatcoke@gmail.com
- Removed the link as source. It seems very hard to determine the
  exactly link with sourceforge.
* Wed Nov 23 2011 dev@dominik-schmidt.de
- put clucene-config.h in %%_libdir/CLucene/ as it's not multilib
  ready and fixfix libclucene-core.pc to know about it [rh#748196]
- put CLuceneConfig.cmake there as well as it only includes version
  information but no include path or link targets
- don't use bundled boost
* Tue Nov 15 2011 saschpe@suse.de
- Honor shared library policy:
  * Obsolete devel package, introduce libclucene0 + libclucene-devel
- Simplified cmake usage, no need for that many env vars
* Fri Nov 11 2011 dev@dominik-schmidt.de
- Update to 2.3.3.4:
  * Static object fields have been changed to method accessors
    Classes changed: FieldCache, ScoreDocComparator.
    This was necessary for creating static libraries work on certain
    platforms.
  * Folders were reorganised, this seems like a good time to do it
  * Some deprecated functions were removed.
  * moved platform configuration type code and utility code into
    'shared' project. This enables tests to be built with a shared
    library on windows
  * Moved moved of the platform specific logic into cmake in order
    to reduce #ifdefs in code
  * added contributions code into the trunk. this will hopefully mean
    more exposure to the contributions.
  * Deletor::Array was renamed to Deletor::vArray.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Sep 14 2011 idonmez@suse.com
- Fix license string to be LGPL-2.1 or Apache-2.0 , bnc#717711
* Tue Sep 13 2011 idonmez@suse.com
- Fix license string
- Use the correct tarball URL
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon May 18 2009 dmueller@suse.de
- fix build with gcc 4.4
* Wed Jan 28 2009 crrodriguez@suse.de
- remove "la" files
* Sun Sep 21 2008 stbinner@suse.de
- update to 0.9.21: no changelog available
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Oct  8 2007 dmueller@suse.de
- update to 0.9.20:
  * no changelog available
* Mon Mar 12 2007 dmueller@suse.de
- disable static libs
- remove reuters test data from tarball (#253602)
* Fri Mar  9 2007 dmueller@suse.de
- Initial package (0.9.16, taken from server:search)
